#include <sstream>
#include <vector>
#include "Customer.h"

using std::ostringstream;
using std::vector;

Customer::Customer() {}

Customer::Customer(const std::string &name)
        : name(name) {}

void Customer::addRental(const Rental &arg) {
    rentals.push_back(arg);
}

std::string Customer::getName() const {
    return name;
}

std::string Customer::statement() {
    double totalAmount = 0;
    int frequentRenterPoints = 0;
    ostringstream result;
    result << "Rental Record for " << getName() << "\n";
    for (auto rental : rentals) {
        double thisAmount = rental.getCharge();
        frequentRenterPoints = rental.getFrequentRenterPoints();

        // show figures for this rental
        result << "\t" << rental.getMovie().getTitle() << "\t"
               << thisAmount << "\n";
        totalAmount += thisAmount;
    }
    // add footer lines
    result << "Amount owed is " << totalAmount << "\n";
    result << "You earned " << frequentRenterPoints
           << " frequent renter points";
    return result.str();
}

std::string Customer::statementHTML() {
    double totalAmount = 0;
    int frequentRenterPoints = 0;
    ostringstream result;
    result << "<h1>Rental Record for <em>" << getName() << "</em></h1>\n";
    for (auto rental : rentals) {
        double thisAmount = rental.getCharge();
        frequentRenterPoints = rental.getFrequentRenterPoints();

        // show figures for this rental
        result << rental.getMovie().getTitle() << ": "
               << thisAmount << "<br/>\n";
        totalAmount += thisAmount;
    }
    // add footer lines
    result << "<p>Amount owed is <em>" << totalAmount << "</em></p>\n";
    result << "<p>You earned <em>" << frequentRenterPoints
           << "</em> frequent renter points</p>\n";
    return result.str();
}

